// -*- C++ -*-
//
// This is the implementation of the non-inlined, non-templated member
// functions of the Parton class.
//

#include "Parton.h"
#include "DipoleState.h"
#include "Dipole.h"
#include "String.h"
#include "ThePEG/PDT/ParticleData.h"
#include "ThePEG/PDT/EnumParticles.h"
#include "ThePEG/EventRecord/Particle.h"

#ifdef ThePEG_TEMPLATES_IN_CC_FILE
// #include "Parton.tcc"
#endif

#include "ThePEG/Persistency/PersistentOStream.h"
#include "ThePEG/Persistency/PersistentIStream.h"

using namespace Ariadne;

ClonePtr Parton::clone() const {
  return new_ptr(*this);
}

void Parton::parent(tcPPtr x) {
  theParent = x;
  data(x->dataPtr());
  theMomentum = x->momentum();
}

void Parton::data(tcPDPtr x) {
  theDataPtr = x;
  isGluon = ( data().id() == ParticleID::g );
}

tParPtr Parton::prev() const {
  return iDip()? iDip()->iPart(): tParPtr();
}

tParPtr Parton::next() const {
  return oDip()? oDip()->oPart(): tParPtr();
}

void Parton::fillReferences(CloneSet & cset) {
  CascadeBase::fillReferences(cset);
  cset.insert(iDip());
  cset.insert(oDip());
}

void Parton::rebind(const TranslationMap & trans) {
  CascadeBase::rebind(trans);
  theIDip = trans.translate(theIDip);
  theODip = trans.translate(theODip);
  theParents.first = trans.translate(theParents.first);
  theParents.second = trans.translate(theParents.second);
  theString = trans.translate(theString);
}

void Parton::persistentOutput(PersistentOStream & os) const {
  os << theParent << theParents << theDataPtr << isGluon
     << ounit(theMomentum, GeV) << theString << theIDip << theODip;
}

void Parton::persistentInput(PersistentIStream & is, int) {
  is >> theParent >> theParents >> theDataPtr >> isGluon
     >> iunit(theMomentum, GeV) >> theString >> theIDip >> theODip;
}

ClassDescription<Parton> Parton::initParton;
// Definition of the static class description member.

void Parton::Init() {}

