// -*- C++ -*-
//
// This is the implementation of the non-inlined, non-templated member
// functions of the String class.
//

#include "String.h"
#include "DipoleState.h"
#include "Parton.h"
#include "Dipole.h"

#ifdef ThePEG_TEMPLATES_IN_CC_FILE
// #include "String.tcc"
#endif

#include "ThePEG/Persistency/PersistentOStream.h"
#include "ThePEG/Persistency/PersistentIStream.h"

using namespace Ariadne;

void String::split(tParPtr g, tParPtr q, tParPtr qbar) {

  // Connect dipoles
  tDipPtr odip = g->oDip();
  tDipPtr idip = g->iDip();
  odip->iPart(qbar);
  qbar->oDip(odip);
  idip->oPart(q);
  q->iDip(idip);

  // Remove gluon from DipoleState
  state()->remove(g);

  // If string was closed, simply break it.
  if ( endpoints().first->isG() ) {
    endpoints(qbar, q);
    qbar->string(this);
    q->string(this);
    return;
  }

  // If open string create a new one starting it qith qbar, ending
  // this with q.
  StrPtr s = state()->create<String>();
  s->endpoints(qbar, endpoints().second);
  endpoints(endpoints().first, q);

  // Connect partons to correct string.
  q->string(this);

  tParPtr p = qbar;
  do {
    p->string(s);
  } while ( p = p->next() );

}

ClonePtr String::clone() const {
  return new_ptr(*this);
}

void String::persistentOutput(PersistentOStream & os) const {
  os << theEndpoints;
}

void String::persistentInput(PersistentIStream & is, int) {
  is >> theEndpoints;
}

ClassDescription<String> String::initString;
// Definition of the static class description member.

void String::Init() {}

