  static ClassDocumentation<StringFragmentation> documentation
    ("The StringFragmentation class is a straight interface to the Lund "
     "string fragmentation routines in Pythia 8.",
     "Hadronization performed according to the "
     "Lund String Fragmentation scheme \\cite{And83} as implemented in "
     "Pythia\\cite{Sjostrand:2007gs,Sjostrand:2006za} version 8.132.",
     "\\bibitem{And83} B.~Andersson, G.~Gustafson, "
     "G.~Ingelman and T.~Sj\\\"ostrand"
     "\n Phys.~Rep.~{\\bf 97} (1983) 31.\n"
     "\\bibitem{Sjostrand:2007gs} T.~Sj\\\"ostrand, S.~Mrenna, P.~Skands, "
     "Comput.~Phys.~Commun.\\ {\\bf 178} (2008) 852.\n"
     "\\bibitem{Sjostrand:2006za} T.~Sj\\\"ostrand, S.~Mrenna, P.~Skands, "
     "JHEP06~(2006)~026.");

  static Switch<StringFragmentation,bool> interfaceHadronLevel_all
    ("HadronLevel_all",
     " If off then stop the generation after the hard process and  parton-level activity has been generated, but before the  hadron-level steps. ",
     &StringFragmentation::theHadronLevel_all, true, true, false);
  static SwitchOption interfaceHadronLevel_allOn
    (interfaceHadronLevel_all,
     "On",
     "On",
     true);
  static SwitchOption interfaceHadronLevel_allOff
    (interfaceHadronLevel_all,
     "Off",
     "Off",
     false);

  static Switch<StringFragmentation,bool> interfaceHadronLevel_Hadronize
    ("HadronLevel_Hadronize",
     " Master switch for hadronization; on/off = true/false. Further options are found in the 'Fragmentation' section of the online Pythia8 manual. ",
     &StringFragmentation::theHadronLevel_Hadronize, true, true, false);
  static SwitchOption interfaceHadronLevel_HadronizeOn
    (interfaceHadronLevel_Hadronize,
     "On",
     "On",
     true);
  static SwitchOption interfaceHadronLevel_HadronizeOff
    (interfaceHadronLevel_Hadronize,
     "Off",
     "Off",
     false);

  static Switch<StringFragmentation,bool> interfaceHadronLevel_Decay
    ("HadronLevel_Decay",
     " Master switch for decays; on/off = true/false. Further options are found in the 'ParticleDecays' section of the online Pythia8 manual. ",
     &StringFragmentation::theHadronLevel_Decay, true, true, false);
  static SwitchOption interfaceHadronLevel_DecayOn
    (interfaceHadronLevel_Decay,
     "On",
     "On",
     true);
  static SwitchOption interfaceHadronLevel_DecayOff
    (interfaceHadronLevel_Decay,
     "Off",
     "Off",
     false);

  static Switch<StringFragmentation,bool> interfaceHadronLevel_BoseEinstein
    ("HadronLevel_BoseEinstein",
     " Master switch for the simulation of Bose-Einstein effects;  on/off = true/false. Further options are found  in the 'BoseEinsteinEffects' section of the online Pythia8 manual. ",
     &StringFragmentation::theHadronLevel_BoseEinstein, false, true, false);
  static SwitchOption interfaceHadronLevel_BoseEinsteinOn
    (interfaceHadronLevel_BoseEinstein,
     "On",
     "On",
     true);
  static SwitchOption interfaceHadronLevel_BoseEinsteinOff
    (interfaceHadronLevel_BoseEinstein,
     "Off",
     "Off",
     false);

  static Parameter<StringFragmentation,double> interfaceStringZ_aLund
    ("StringZ_aLund",
     " The \\f$a\\f$ parameter of the Lund symmetric fragmentation function. ",
     &StringFragmentation::theStringZ_aLund, 0.3, 0.0, 2.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringZ_bLund
    ("StringZ_bLund",
     " The \\f$b\\f$ parameter of the Lund symmetric fragmentation function. ",
     &StringFragmentation::theStringZ_bLund, 0.8, 0.2, 2.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringZ_aExtraDiquark
    ("StringZ_aExtraDiquark",
     " allows a larger \\f$a\\f$ for diquarks, with total  \\f$a = aLund + aExtraDiquark\\f$. ",
     &StringFragmentation::theStringZ_aExtraDiquark, 0.5, 0.0, 2.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringZ_rFactC
    ("StringZ_rFactC",
     " \\f$r_c\\f$, i.e. the above parameter for \\f$c\\f$ quarks. ",
     &StringFragmentation::theStringZ_rFactC, 1.0, 0.0, 2.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringZ_rFactB
    ("StringZ_rFactB",
     " \\f$r_b\\f$, i.e. the above parameter for \\f$b\\f$ quarks. ",
     &StringFragmentation::theStringZ_rFactB, 0.67, 0.0, 2.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringZ_rFactH
    ("StringZ_rFactH",
     " \\f$r_h\\f$, i.e. the above parameter for heavier hypothetical quarks, or in general any new coloured particle long-lived enough to hadronize. ",
     &StringFragmentation::theStringZ_rFactH, 1.0, 0.0, 2.0,
     true, false, Interface::limited);

  static Switch<StringFragmentation,bool> interfaceStringZ_usePetersonC
    ("StringZ_usePetersonC",
     " use Peterson for \\f$c\\f$ quarks. ",
     &StringFragmentation::theStringZ_usePetersonC, false, true, false);
  static SwitchOption interfaceStringZ_usePetersonCOn
    (interfaceStringZ_usePetersonC,
     "On",
     "On",
     true);
  static SwitchOption interfaceStringZ_usePetersonCOff
    (interfaceStringZ_usePetersonC,
     "Off",
     "Off",
     false);

  static Switch<StringFragmentation,bool> interfaceStringZ_usePetersonB
    ("StringZ_usePetersonB",
     " use Peterson for \\f$b\\f$ quarks. ",
     &StringFragmentation::theStringZ_usePetersonB, false, true, false);
  static SwitchOption interfaceStringZ_usePetersonBOn
    (interfaceStringZ_usePetersonB,
     "On",
     "On",
     true);
  static SwitchOption interfaceStringZ_usePetersonBOff
    (interfaceStringZ_usePetersonB,
     "Off",
     "Off",
     false);

  static Switch<StringFragmentation,bool> interfaceStringZ_usePetersonH
    ("StringZ_usePetersonH",
     " use Peterson for hypothetical heavier quarks. ",
     &StringFragmentation::theStringZ_usePetersonH, false, true, false);
  static SwitchOption interfaceStringZ_usePetersonHOn
    (interfaceStringZ_usePetersonH,
     "On",
     "On",
     true);
  static SwitchOption interfaceStringZ_usePetersonHOff
    (interfaceStringZ_usePetersonH,
     "Off",
     "Off",
     false);

  static Parameter<StringFragmentation,double> interfaceStringZ_epsilonC
    ("StringZ_epsilonC",
     " \\f$epsilon_c\\f$, i.e. the above parameter for \\f$c\\f$ quarks. ",
     &StringFragmentation::theStringZ_epsilonC, 0.05, 0.01, 0.25,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringZ_epsilonB
    ("StringZ_epsilonB",
     " \\f$epsilon_b\\f$, i.e. the above parameter for \\f$b\\f$ quarks. ",
     &StringFragmentation::theStringZ_epsilonB, 0.005, 0.001, 0.025,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringZ_epsilonH
    ("StringZ_epsilonH",
     " \\f$epsilon_h\\f$, i.e. the above parameter for hypothetical heavier  quarks, normalized to the case where \\f$m_h = m_b\\f$. The actually  used parameter is then \\f$epsilon = epsilon_h * (m_b^2 / m_h^2)\\f$. This allows a sensible scaling to a particle with an unknown higher mass without the need for a user intervention.  ",
     &StringFragmentation::theStringZ_epsilonH, 0.005, 0.0001, 0.25,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringPT_sigma
    ("StringPT_sigma",
     " the width \\f$sigma\\f$ in the fragmentation process. ",
     &StringFragmentation::theStringPT_sigma, 0.304, 0.0, 1.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringPT_enhancedFraction
    ("StringPT_enhancedFraction",
     " \\f$enhancedFraction\\f$,the fraction of string breaks with enhanced  width. ",
     &StringFragmentation::theStringPT_enhancedFraction, 0.01, 0.0, 0.1,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringPT_enhancedWidth
    ("StringPT_enhancedWidth",
     " \\f$enhancedWidth\\f$,the enhancement of the width in this fraction. ",
     &StringFragmentation::theStringPT_enhancedWidth, 2.0, 1.0, 5.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFragmentation_stopMass
    ("StringFragmentation_stopMass",
     " Is used to define a \\f$W_min = m_q1 + m_q2 + stopMass\\f$, where \\f$m_q1\\f$ and \\f$m_q2\\f$ are the masses of the two  current endpoint quarks or diquarks.  ",
     &StringFragmentation::theStringFragmentation_stopMass, 1.0, 0.0, 2.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFragmentation_stopNewFlav
    ("StringFragmentation_stopNewFlav",
     " Add to \\f$W_min\\f$ an amount \\f$stopNewFlav * m_{q,last}\\f$,  where \\f$q_last\\f$ is the last \\f$q qbar\\f$ pair produced  between the final two hadrons. ",
     &StringFragmentation::theStringFragmentation_stopNewFlav, 2.0, 0.0, 2.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFragmentation_stopSmear
    ("StringFragmentation_stopSmear",
     " The \\f$W_min\\f$ above is then smeared uniformly in the range \\f$W_min_smeared = W_min * [ 1 - stopSmear, 1 + stopSmear ]\\f$. ",
     &StringFragmentation::theStringFragmentation_stopSmear, 0.2, 0.0, 0.5,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceHadronLevel_mStringMin
    ("HadronLevel_mStringMin",
     " Decides whether a partonic system should be considered as a normal string or a ministring, the latter only producing one or two primary hadrons. The system mass should be above \\f$mStringMin\\f$ plus the  sum of quark/diquark constituent masses for a normal string description, else the ministring scenario is used. ",
     &StringFragmentation::theHadronLevel_mStringMin, 1., 0.5, 1.5,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceFragmentationSystems_mJoin
    ("FragmentationSystems_mJoin",
     " When two colour-connected partons are very nearby, with at least  one being a gluon, they can be joined into one, to avoid technical  problems of very small string regions. The requirement for joining is  that the invariant mass of the pair is below \\f$mJoin\\f$, where a  gluon only counts with half its momentum, i.e. with its contribution  to the string region under consideration. (Note that, for technical  reasons, the 0.2 GeV lower limit is de facto hardcoded.) ",
     &StringFragmentation::theFragmentationSystems_mJoin, 0.2, 0.2, 1.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceFragmentationSystems_mJoinJunction
    ("FragmentationSystems_mJoinJunction",
     " When the invariant mass of two of the quarks in a three-quark junction  string system becomes too small, the system is simplified to a  quark-diquark simple string. The requirement for this simplification  is that the diquark mass, minus the two quark masses, falls below  \\f$mJoinJunction\\f$. Gluons on the string between the junction and  the respective quark, if any, are counted as part of the quark  four-momentum. Those on the two combined legs are clustered with the  diquark when it is formed. ",
     &StringFragmentation::theFragmentationSystems_mJoinJunction, 1.0, 0.5, 2.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,int> interfaceMiniStringFragmentation_nTry
    ("MiniStringFragmentation_nTry",
     " Whenever the machinery is called, first this many attempts are made to pick two hadrons that the system fragments to. If the hadrons are  too massive the attempt will fail, but a new subsequent try could involve other flavour and hadrons and thus still succeed.  After \\f$nTry\\f$ attempts, instead an attempt is made to produce a  single hadron from the system. Should also this fail, some further attempts at obtaining two hadrons will be made before eventually  giving up. ",
     &StringFragmentation::theMiniStringFragmentation_nTry, 2, 1, 10,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFragmentation_eNormJunction
    ("StringFragmentation_eNormJunction",
     " Used to find the effective rest frame of the junction, which is complicated when the three string legs may contain additional gluons between the junction and the endpoint. To this end, a pull is defined as a weighed sum of the momenta on each leg,  where the weight is \\f$exp(- eSum / eNormJunction)\\f$, with  \\f$eSum\\f$ the summed energy of all partons closer to the junction  than the currently considered one (in the junction rest frame).  Should in principle be (close to) \\f$sqrt((1 + a) / b)\\f$, with  \\f$a\\f$ and \\f$b\\f$ the parameters of the Lund symmetric  fragmentation function.  ",
     &StringFragmentation::theStringFragmentation_eNormJunction, 2.0, 0.5, 10,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFragmentation_eBothLeftJunction
    ("StringFragmentation_eBothLeftJunction",
     " Retry (up to 10 times) when the first two considered strings in to a  junction both have a remaining energy (in the junction rest frame)  above this number. ",
     &StringFragmentation::theStringFragmentation_eBothLeftJunction, 1.0, 0.5, 0.0,
     true, false, Interface::lowerlim);

  static Parameter<StringFragmentation,double> interfaceStringFragmentation_eMaxLeftJunction
    ("StringFragmentation_eMaxLeftJunction",
     "  Retry (up to 10 times) when the first two considered strings in to a  junction has a highest remaining energy (in the junction rest frame)  above a random energy evenly distributed between  \\f$eBothLeftJunction\\f$ and  \\f$eBothLeftJunction + eMaxLeftJunction\\f$  (drawn anew for each test). ",
     &StringFragmentation::theStringFragmentation_eMaxLeftJunction, 10.0, 0., 0.0,
     true, false, Interface::lowerlim);

  static Parameter<StringFragmentation,double> interfaceStringFragmentation_eMinLeftJunction
    ("StringFragmentation_eMinLeftJunction",
     "  Retry (up to 10 times) when the invariant mass-squared of the final leg  and the leftover momentum of the first two treated legs falls below  \\f$eMinLeftJunction\\f$ times the energy of the final leg (in the  junction rest frame).  ",
     &StringFragmentation::theStringFragmentation_eMinLeftJunction, 0.2, 0., 0.0,
     true, false, Interface::lowerlim);

  static ParVector<StringFragmentation,string> interfaceAdditionalP8Settings
    ("AdditionalP8Settings",
     "Each string in this vector will be sent to the Pythia8 Settings "
     "object using the Pythia::readString function. Note that most relevant "
     "settings are already available as normal ThePEG interfaces, and that "
     "this interface should be used with care.",
     &StringFragmentation::theAdditionalP8Settings, -1, "", "", "",
     true, false, Interface::nolimits);

